.. _opzet:

OPZET
#####

Aan de (F)ACT methodiek kan men zien dat men een opzet tot vergiftigen heeft, men zegt het toedienen van gif “verantwoord” te kunnen doen:

| men huurt een arts in om te zorgen dat de vergiftiging zorgvuldig gebeurd.
| men zegt dat de dosis geen schade kan.
| men geeft een bijsluiter voor de schade die men wel op kan doen.
| men zegt de dosering binnen een bandbreedte te houden.
| men zegt op de vergiftigings symptomen te letten dat ze tijdig opgemerkt worden zodat men de dosis kan verlagen.
| men zegt een snelle teruggang naar het ziekenhuis te bieden in geval van acute vergiftiging.
